% Mulab analysis toolbox
% Version 1.02 - January 2009
%
% USER COMMANDS
%
%   MULAB        - Initializes (preferences from MULAB.mat or defaults)
%                  including facility, data format, filenames ...
%   MUFIT_GUI    - General GUI interface: load, fit, plot ...
%                  For a description and tutorial see the webpages
%                  If you want to access data see also MU_GLOBALS 
%
%  Functions usable also from command window   
%
%   MURIG         - Changes facility, data format, filenames ... 
%   MULABSAVE     - Saves MULAB.mat in local directory (pwd to show)
%
%   MUCD          - Changes data path (gui)
%   MULOAD        - Loads runs from ISIS (mcs,nxs) and PSI (ascii,bin)
%   MUADD         - Adds a run to previously loaded run(s)
%   MULIST        - Lists headers of runs in log directory (saves to readme)  
%
%   MUPLOT        - Produces different standard plots (TODO)
%   MUSET         - Fits t=0  and background (PSI only)
%   MUMODEL       - Selects model: switch between gui dialogs to
%                  edit fit parameters, load or create model
%   MUSAVEMODEL   - Saves fit model e.g. as damu.fit (-mat format)
%   MUEDITMODEL   - Append/delete/replace components, or Erase model
%   MUFITMENU     - Selects range, alpha, bin, grouping, fit type (gui)
%   MUPLOTFIT     - Plots fit stating guess and fit results (auto) 
%
%   MUFIT         - Performs fit with chosen model on chosen grouping
%   MUUPDATEMODEL - Updates starting guess values with last best fit
%   MUFFTRES      - Fourier transform of fit residues
%
% INTERNAL FUNCTIONS
%
%           LOAD DATA, PRESET DATA AND PARAMETERS
%
%   mupath       - Selects data path and log path  
%   isisload     - Loads old ISIS MCS data format 
%   nxsload      - Loads new ISIS NeXus data format
%   psiload      - Loads PSI data format
%   muedge       - Defines the fit function for the ISIS beam time
%                  structure  
%   muasymmetry  - Fills TIME ASYMMETRY and ASYMERROR in global MU_DATA
%   mu_globals   - Readme file describing MULAB globals
%
%           GENERAL UTILITIES
%
%   mutxtmenu    - Generates a menu in the command window, muzen-style
%   valerror     - Produces the string 3.2(1) from 3.244 and 0.127  
%   muchi2cdf    - Calculates probability of lower chi2 than obtained
%   mugroup      - Translates grouping from array of integers to string
%   musgroup     - Translates string grouping to integer array format
%   mugrouptag   - Creates a short tag to identify grouping in filenames
%   mucomments   - Prints comments from present run header
%
%           MULAB FIT 
% 
%   mu_initialize_models - Defines the standard set of model components for
%                          the FMINUIT fit
%   fminuit              - Matlab port of Frank James' Cernlib program 
%   fcn                  - Main fit function
%   mucomp               - From FMINUIT par list to MU_COMPONENT
%   mupar                - From FMINUIT par list to MU_COMPONENT and more
%   mucountpar           - Counts parameters in the present MU_MODEL
%   mucreatemodel        - Creates a new model
%   muldmodel            - Loads fit model
%   mulistcomponents     - Lists components available in MU_COMPONENT
%   mumodellist          - Lists components in present MU_MODEL
%   mugetcomponent       - Unpacks the conventional model name into
%                          its components
%   mumodeldisplay       - Edits model parameters
%   muextractparameter   - Reads parameter answers from inputdlg  
%   musummary            - Fit summary in command window and in files
%   muparse              - Parsing parameter flags for linear
%                          relations (not implemented in fcn yet)
%   muextractflag        - Reads string answers from mufit_gui                        
%   
%
% TROUBLESHOOTING: The appropriate isis/nxs/psiload.mex... files 
% must be in the same path as their help files. They must also be
% the right ones for the machine architecture 
% (e.g. psiload.mexa64 for linux x86_64)
% Refer to the mulab site: 
%
% http://www.fis.unipr.it/~derenzi/dispense/pmwiki.php?n=MuSR.Analysis
%
% 
% STRATEGIES FOR A FIT FROM SCRATCH:
% 
% set data and log path 
% load data e.g. a TF calibration
% determine t=0 (toolbar menu Setup)
% load an appropriate fit model or create one (type its shorthand
% e.g. damu for the TF calibration
% plotfit to see the initial guess overlayed on your data
% do fit 
% after first fit save mulab (initial settings) 
% optionally plotfit on short time range
% optionally fft the residues, if you see significant deviations
% optionally update if you want to fit next run from this bestfit
% as a guess
% Each fit result is automatically saved, with plenty of 
% run-specific fit infos, into a -mat file, e.g. damu.2134.2-1_1.fit
% To show an old fit in a new session, load the data, then load the fit
% result (muldmodel, choose e.g. damu.2134.2-1_1.fit, then plotfit
%
%
% Copyleft 1983-2008 G. Guidi, original minuit muon fit
%                    R. De Renzi, muzen (parent FORTRAN 77)
%                    G. Allodi, fminuit and data load functions
% Simplified GNU license: you can do whatever you like with this
% toolbox, on your PCs. If you want to recirculate a modified
% version, please let me know: roberto.derenzi at unipr.it subj: mulab

