function mu_initialize_models
% invoked by mulab
% This is the general list of available components
% This function creates a 
% global structure MU_COMPONENT
% with fields NAME
% PARAMETER.NUMBER double (integer)
% PARAMETER.NAME cell array
% PARAMETER.TYPE cell array (unlim positive limited)
% It further creates the global MU_TABLE
global MU_COMPONENT
global MU_TABLE
MU_COMPONENT=[]; % reset
MU_TABLE=[];     % reset
MU_TABLE.GAMU=0.01355; % MHz/G
MU_TABLE.TAUMU=2197.03; % ns
MU_TABLE.GAME=2.8025; % MHz/G
MU_COMPONENT.NAME={'da'};
MU_COMPONENT.PARAMETER.NUMBER=1;
MU_COMPONENT.PARAMETER.NAME={'lpha'};
MU_COMPONENT.PARAMETER.TYPE={'unlim'};
MU_COMPONENT.DEFINITION={'zeros(size(data(1,:)))'}; 
MU_COMPONENT.HELP={'alpha correction'};
% correction factor, not a component
MU_COMPONENT.NAME(2)={'ba'};  % decaying amplitude, lorentzian or gaussian
MU_COMPONENT.PARAMETER(2).NUMBER=3;
MU_COMPONENT.PARAMETER(2).NAME={'Amp','DeLo','DeGa'};
MU_COMPONENT.PARAMETER(2).TYPE={'unlim','unlim','unlim'};
MU_COMPONENT.DEFINITION(2)={['p(1)*' ...
         'exp(-data(1,:)*p(2)).*' ...
         'exp(-((data(1,:)*p(3)).^2)/2)']};
MU_COMPONENT.HELP(2)={['Non-precessing component ' ...
                    ' with Lorentzian/Gaussian relaxation']};
MU_COMPONENT.NAME(3)={'mu'};
MU_COMPONENT.PARAMETER(3).NUMBER=5;
MU_COMPONENT.PARAMETER(3).NAME={'Amp','Gau','Phi','DeLo','DeGa'};
MU_COMPONENT.PARAMETER(3).TYPE={'unlim','unlim','unlim','unlim','unlim'};
MU_COMPONENT.DEFINITION(3)={['p(1)*' ...
        'cos(2*pi*(MU_TABLE.GAMU*p(2)*' ...
        'data(1,:)+p(3)/360)).*' ...
        'exp(-data(1,:)*p(4)).*' ...
        'exp(-((data(1,:)*p(5)).^2)/2)']};
MU_COMPONENT.HELP(3)={['Precessing armonic component ' ...
                    'with Lorentzian/Gaussian relaxation']} ;
MU_COMPONENT.NAME(4)={'bj'};
MU_COMPONENT.PARAMETER(4).NUMBER=5;
MU_COMPONENT.PARAMETER(4).NAME={'Amp','Gau','Phi','DeLo','DeGa'};
MU_COMPONENT.PARAMETER(4).TYPE={'unlim','unlim','unlim','unlim', ...
                    'unlim'};
MU_COMPONENT.DEFINITION(4)={['p(1)*' ...
        'besselj(0,2*pi*(MU_TABLE.GAMU*p(2)*' ...
        'data(1,:)+p(3)/360)).*' ...
        'exp(-data(1,:)*p(4)).*' ...
        'exp(-((data(1,:)*p(5)).^2)/2)']};
MU_COMPONENT.HELP(4)={['Precessing Bessel J0 component' ...
                    'with Lorentzian/Gaussian relaxation']} ;
MU_COMPONENT.NAME(5)={'st'};
MU_COMPONENT.PARAMETER(5).NUMBER=5;
MU_COMPONENT.PARAMETER(5).NAME={'Amp','Gau','Phi','DecR','Beta'};
MU_COMPONENT.PARAMETER(5).TYPE={'unlim','unlim','unlim','positive','limited'};
MU_COMPONENT.DEFINITION(5)={['p(1)*' ...
        'cos(2*pi*(MU_TABLE.GAMU*p(2)*' ...
        'data(1,:)+p(3)/360)).*' ...
        'exp(-(data(1,:)*p(4)).^' ...
        'p(5))']};
MU_COMPONENT.HELP(5)={['Precessing armonic component' ...
                    'with stretched exponential relaxation']} ;
MU_COMPONENT.NAME(6)={'kg'};
MU_COMPONENT.PARAMETER(6).NUMBER=4;
MU_COMPONENT.PARAMETER(6).NAME={'Amp','LFG','DeG','DeLo'};
MU_COMPONENT.PARAMETER(6).TYPE={'unlim','positive','positive','unlim'};
MU_COMPONENT.DEFINITION(6)={'mukubogauss(p,data)'};
MU_COMPONENT.HELP(6)={['Kubo Toyabe suite, Gaussian' ...
                    'static in zero or longitudinal field, with T1']} ;
MU_COMPONENT.NAME(7)={'kl'};
MU_COMPONENT.PARAMETER(7).NUMBER=4;
MU_COMPONENT.PARAMETER(7).NAME={'Amp','LFG','DeL','DeLo'};
MU_COMPONENT.PARAMETER(7).TYPE={'unlim','positive','positive','unlim'};
MU_COMPONENT.DEFINITION(7)={'mukubolorentz(p,data)'};
MU_COMPONENT.HELP(7)={['Kubo Toyabe suite, Lorentzian' ...
                    'static in zero or longitudinal field, with T1']} ;

MU_COMPONENT.NAME(8)={'mt'};
MU_COMPONENT.PARAMETER(8).NUMBER=8;
MU_COMPONENT.PARAMETER(8).NAME={'Amp','Hyp','Gau','Phi',...
                    'DeLo','DeGa','DeLo','DeGa'};
MU_COMPONENT.PARAMETER(8).TYPE={'unlim','unlim','unlim','unlim',...
                   'unlim','unlim','unlim','unlim'};
MU_COMPONENT.DEFINITION(8)={'muoniumtriplet(p,data)'};
MU_COMPONENT.HELP(8)={['Muonium triplet, ' ...
                    'static in transverse field, with independent rates']} ;

