function muasymmetry(varargin)
% usage MUASYMMETRY
%
% for MUFIT reads MU_MODEL.GROUPING and loads into MU_DATA.TIME
% MU_DATA.ASYMMETRY and MU_DATA.ASYMERROR
%
% usage MUASIMMETRY(1)
%
% for MUPLOT reads MU_PLOT.GROUPING and loads into MU_PLOT.TIME and
% MU_PLOT.ASYMMETRY

global MU_DATA MU_MODEL MU_GEAR MU_TABLE MU_PLOT
  
if isempty(varargin)
    % MUFIT version
    histos=[MU_MODEL.GROUPING(1).FORWARD ...
            MU_MODEL.GROUPING(1).BACKWARD]; % full grouping
else
    % MUPLOT version
    histos=[MU_PLOT.GROUPING(1).FORWARD ...
            MU_PLOT.GROUPING(1).BACKWARD]; % full grouping        
end
off=MU_GEAR.OFFSET;
switch MU_GEAR.FACILITY
  case 'PSI'
    lengthdata=size(MU_DATA.DATA,1)-max(MU_DATA.NT0(histos))-off+1;
    % calculate background on pre-prompt region
    % histos are zeros initially, then they count background
    % until the prompt (t=0) followed by positrons from the 
    % muon decays for t>=0. Background is the average of the
    % pre-prompt region, 
    bkg=[];
    bins=[];
    k=0;
    data=zeros(lengthdata,0); % each histogram it is a column vector
    for h=histos
        nt0=MU_DATA.NT0(h);
        k=k+1;
        firstbkg=min(find(MU_DATA.DATA(1:end-1000,h)))+MU_GEAR.LBG; % first
                                                          % bin for
                                                          % background        
        lastbkg=nt0-MU_GEAR.RBG; % last bin for bakground guess
        initial=nt0+off-1;  % first bin is MU_GEAR.OFFSET-1  bins after
                            % that containing t=0 (MU_GEAR.OFFSET=1
                            % starts from t=0)
        
        bins=[initial:initial+lengthdata-1];
                                                   % for each histo
        bkg=mean(MU_DATA.DATA(firstbkg:lastbkg,h));
        data=[data MU_DATA.DATA(bins,h)-ones(lengthdata,1)*bkg]; 
    end
    % nt0(h) contains time t=0     
    %background subtraction only on used histos
  case 'ISIS'
    nt0=MU_DATA.NT0(histos(1)); % t=0 bins for all histo in the grouping
                                % all histo in
                                % the chosen grouping
                                % equal for all histos at ISIS
    lengthdata=size(MU_DATA.DATA,1)-nt0-off+1;
    initial=nt0+off-1;  % first bin is MU_GEAR.OFFSET-1  bins after
                        % that containing t=0 (MU_GEAR.OFFSET=1
                        % starts from t=0)
    bins=[initial:initial+lengthdata-1];
    k=0;
    data=zeros(lengthdata,0); % each histogram it is a column vector
    for h=histos
        k=k+1;
        data=[data MU_DATA.DATA(bins,h)]; 
    end
end

if isempty(varargin)
    % MUFIT version
    weightplus=[ones(size(MU_MODEL.GROUPING(1).FORWARD)) ...
                MU_MODEL.ALPHA*ones(size(MU_MODEL.GROUPING(1).BACKWARD))]';
else
    % MUPLOT version
    weightplus=[ones(size(MU_PLOT.GROUPING(1).FORWARD)) ...
                MU_PLOT.ALPHA*ones(size(MU_PLOT.GROUPING(1).BACKWARD))]';
end
% for the denominator of the asymmetry function
dt=MU_DATA.DT(histos); % distance of t=0 from center of bin NT0
dt=mean(dt); % take average over histos in this grouping
             %
             % now fit N0 for the denominator in polarization
Y=(data* ...
  weightplus)'; % sum of all histos
% eX=sqrt(data*(weightplus.^2)'); % sigma^2=data*weight^2, 
% a=X(1);
% not needed with polyfit
X=exp((-(off-1+[0:lengthdata-1])*MU_DATA.RESNS-dt)/MU_TABLE.TAUMU);
N0=polyfit(X,Y,1); % fits Y vs exp(-time(ns)/taumu(ns))
N0=N0(1);


if isempty(varargin)
    % MUFIT version
    weight=[ones(size(MU_MODEL.GROUPING(1).FORWARD)) ...
            (-MU_MODEL.ALPHA)* ...
            ones(size(MU_MODEL.GROUPING(1).BACKWARD))]';
    MU_DATA.TIME=((off-1+[0:lengthdata-1]')*MU_DATA.RESNS-dt)'/1000; 
    % including offset and fine adjustment dt, finally transformed in musec
    MU_DATA.ASYMMETRY=((data*weight/N0).*exp(MU_DATA.TIME'/ ...
                                             (MU_TABLE.TAUMU/1e3)))';
    % here taumu is in mus
    MU_DATA.ASYMERROR=(sqrt(data*(weight.^2))/N0...
                       .*exp(MU_DATA.TIME'/(MU_TABLE.TAUMU/1e3)))';
else
    % MUPLOT version
    weight=[ones(size(MU_PLOT.GROUPING(1).FORWARD)) ...
        (-MU_PLOT.ALPHA)* ...
        ones(size(MU_PLOT.GROUPING(1).BACKWARD))]';
    MU_PLOT.TIME=((off-1+[0:lengthdata-1]')*MU_DATA.RESNS-dt)'/1000; 
    % including offset and fine adjustment dt, finally transformed in musec
    MU_PLOT.ASYMMETRY=((data*weight/N0).*exp(MU_DATA.TIME'/ ...
                                         (MU_TABLE.TAUMU/1e3)))';
    % here taumu is in mus
end


