function f=muktg(p,data)
% F=MUKTG(P,DATA)
% calculates point by point (slow)
% static Kubo-Toyabe relaxation with external
% longitudinal field (normally fixed)
% p(1)=amplitude  p(2)=field (Gauss) p(3)=decay Gau usec-1
% for zero field analytical formula 
% p(1)/3*(1+2*(1-(p(3)*t).^2).*exp(-(p(3)*t).^2 /2);
% for finite fields integral of kernel given in 
%
% http://www.fis.unipr.it/~derenzi/dispense/pmwiki.php?n=MuSR.KuboFunctions
  
global MU_TABLE

if p(3)==0
    f=p(1)*ones(size(data(1,:))); % no relaxation
else
    if abs(p(2)/p(3))<2.5e-7, % consider zero field 
        Dtt=(p(3)*data(1,:)).^2;
        f=p(1)/3*(1+2*(1-Dtt).*exp(-Dtt/2));
    else % calculate integral with kernel for Gauss KT        
        w0=2*pi*MU_TABLE.GAMU*p(2);
        kernel=@(x) (sin(w0*x)*(p(3)^4/w0^3-p(3)^2/w0)...
                     -p(3)^3/w0^2*p(3).*x.* ...
                     cos(w0*x)).*exp(-p(3)^2*x.^2/2);
        % the integral from 0 to 1.4 of this kernel is provided by
        % quad(kernel,0,1.4)
        % in order to calculate f(t)=1+2*D^2*quad(kernel,0,t)
        % more efficiently we calculate the starting point and the increments
        % criterio: calcolare su meno punti
        start=min(find(data(1,:)>0)); % first positive time
        dt=data(1,2)-data(1,1); % time increment
        stop=length(data(1,:)); 
        t=data(1,start);
        f=zeros(1,stop);
        f(start)=quad(kernel,0,t); % first nonzero integral
        for k=start+1:stop
            tt=t+dt;
            f(k)=quad(kernel,t,tt); % integral increment
            t=tt;
        end
        f=p(1)*(1+2*cumsum(f));
    end
end


