function f=muktl(p,data)
% F=MUKTL(P,DATA)
% calculates point by point (slow)
% static Kubo-Toyabe relaxation with external
% longitudinal field (normally fixed)
% p(1)=amplitude  p(2)=field (Gauss) p(3)=decay Lor usec-1
% for zero field analytical formula 
% p(1)/3*(1+2*(1-(p(3)*t).^2).*exp(-(p(3)*t).^2 /2);
% for finite fields integral of kernel given in 
%
% http://www.fis.unipr.it/~derenzi/dispense/pmwiki.php?n=MuSR.KuboFunctions
  
global MU_TABLE

if p(3)==0
    f=p(1)*ones(size(data(1,:))); % no relaxation
else
    if abs(p(2)/p(3))<2.5e-7, % consider zero field 
        Dtt=p(3)*data(1,:);
        f=p(1)/3*(1+2*(1-Dtt).*exp(-Dtt));
    else % calculate integral with kernel for Gauss KT        
        w0=2*pi*MU_TABLE.GAMU*p(2);
        % from BC , reinterpreted, with sin cos, but with j1 sinc-cos
        kernel=@(x) sin(w0*x)/(w0*x)*exp(-p(3)*x);
        % the integral from 0 to 1.4 of this kernel is provided by
        % quad(kernel,0,1.4)
        % in order to calculate f(t)=1+2*D^2*quad(kernel,0,t)
        % more efficiently we calculate the starting point and the increments
        % criterio: calcolare su meno punti
        start=min(find(data(1,:)>0)); % first positive time
        dt=data(1,2)-data(1,1); % time increment
        stop=length(data(1,:)); 
        t=data(1,start);
        f=zeros(1,stop);
        f(start)=quad(kernel,0,t); % first nonzero integral
        for k=start+1:stop
            tt=t+dt;
            f(k)=quad(kernel,t,tt); % integral increment
            t=tt;
        end
        if data(1,start)==0
            t=data(1,2:end);
            ept=exp(-p(3)*t);
            wt=w0*t;
            j0=sin(wt)./wt; % call it j0 like BC although it is not
            j1=(j0-cos(wt))./wt; % call it j1 like BC although it is not
            fa=[1 ...
                1-p(3)/w0*j1.*ept...
                -(p(3)/w0)^2*(j0.*ept-1)];
        else
            t=data(1,1:end);
            ept=exp(-p(3)*t);
            wt=w0*t;
            j0=sin(wt)./wt; % call it j0 like BC although it is not
            j1=(j0-cos(wt))./wt; % call it j1 like BC although it is not
            fa=1-p(3)/w0*j1.*ept...
                -(p(3)/w0)^2*(j0.*ept-1);
        end
        f=p(1)*(fa-p(3)*(1+(p(3)/w0)^2)*cumsum(f));
    end
end


