function f=mukubolorentz(p,data)
% F=MUKUBOLORENTZ(P,DATA)
% interpolation of calculation over few points
% calculates static Kubo-Toyabe relaxation with external
% longitudinal field (normally fixed)
% p(1)=amplitude  p(2)=field (Gauss) p(3)=decay Gau usec-1
% for zero field analytical formula 
% p(1)/3*(1+2*(1-p(3)*t).*exp(-p(3)*t);
% for finite fields integral of kernel given in 
%
% http://www.fis.unipr.it/~derenzi/dispense/pmwiki.php?n=MuSR.KuboFunctions
% see also MUKTL MUKTG MUKUBOGAUSS   

global MU_TABLE

if p(3)==0
    f=p(1)*ones(size(data(1,:))); % no relaxation
else
    if abs(p(2)/p(3))<2.5e-7, % consider zero field 
        Dtt=p(3)*data(1,:);
        f=p(1)/3*(1+2*(1-Dtt).*exp(-Dtt));
    else % calculate integral with kernel for Gauss KT        
        w0=2*pi*MU_TABLE.GAMU*p(2);
        kernel=@(x) sin(w0*x)/(w0*x)*exp(-p(3)*x);
        % the integral from 0 to 1.4 of this kernel is provided by
        % quad(kernel,0,1.4)
        % in order to calculate f(t)=1+2*D^2*quad(kernel,0,t)
        % more efficiently we calculate the starting point and the increments
        % criterio: calcolare su meno punti
        start=min(find(data(1,:)>0)); % first positive time
        dt=data(1,2)-data(1,1); % time increment
        stop=length(data(1,:)); 
        t=data(1,start);
        f0=max(MU_TABLE.GAMU*p(2),p(3));
        sample=20; % points on a period 
        N=max(floor(1/(f0*dt*sample)),20); % a point every N
        M=length([start:N:stop]);
        ti=zeros(1,M);
        fi=ti; % initialize
        ti(1)=t;
        fi(1)=quad(kernel,0,t); % first nonzero integral
        for k=2:M
            tt=t+N*dt;
            ti(k)=tt;
            fi(k)=quad(kernel,t,tt); % integral increment
            t=tt;
        end
        if ti(end)~=data(1,stop)
            ti(end)=data(1,stop);
            fi(end)=quad(kernel,t-N*dt,ti(end)); % last point must
                                                 % be truely the
                                                 % last one
        end
        if data(1,start)==0 % starts from zero
            t=ti(2:end);
            ept=exp(-p(3)*t);
            wt=w0*t;
            j0=sin(wt)./wt; % call it j0 like BC although it is not
            j1=(j0-cos(wt))./wt; % call it j1 like BC although it is not
            fa=[1 ...
                1-p(3)/w0*j1.*ept...
                -(p(3)/w0)^2*(j0.*ept-1)]; % first point is not
                                           % analytic, set to its limit
        else  % no time is exaclty 0
            ept=exp(-p(3)*ti);
            wt=w0*ti;
            j0=sin(wt)./wt; % call it j0 like BC although it is not
            j1=(j0-cos(wt))./wt; % call it j1 like BC although it is not
            fa=1-p(3)/w0*j1.*ept...
               -(p(3)/w0)^2*(j0.*ept-1); % calculates them all
        end
        % interpolare
        fi=p(1)*(fa-p(3)*(1+(p(3)/w0)^2)*cumsum(fi));
        if start~=1
            f=zeros(1,stop);
            f(start:stop)=interp1(ti,fi,data(1,start:stop));
        else
            f=interp1(ti,fi,data(1,:));
        end
    end
end
f=f.*exp(-data(1,:)*p(4));
