function mulab(varargin)
% usage MULAB
%
% Mulab startup routine.
% Clears globals with warning
% Loads MULAB.mat
% 
% usage MULAB(1)
% After initializing as above it invokes MUFIT_GUI (see its HELP)
% 
%
%   STRATEGIES FOR A FIT FROM SCRATCH:
% 
%   set data and log path 
%   load data e.g. a TF calibration
%   determine t=0 (toolbar menu Setup)
%   load an appropriate fit model or create one (type its shorthand
%   e.g. damu for the TF calibration
%   plotfit to see the initial guess overlayed on your data
%   do fit 
%   after first fit save mulab (initial settings) 
%   optionally plotfit on short time range
%   optionally fft the residues, if you see significant deviations
%   optionally update if you want to fit next run from this bestfit
%   as a guess
%   Each fit result is automatically saved, with plenty of 
%   run-specific fit infos, into a -mat file, e.g. damu.2134.2-1_1.fit
%   To show an old fit in a new session, load the data, then load the fit
%   result (muldmodel, choose e.g. damu.2134.2-1_1.fit, then plotfit
% 
%
%   Copyleft 1983-2008 G. Guidi, original minuit muon fit
%                      R. De Renzi, muzen (parent FORTRAN 77)
%                      G. Allodi, fminuit and data load functions
%   Simplified GNU license: you can do whatever you like with this
%   toolbox, on your PCs. If you want to recirculate a modified
%   version, please let me know: roberto.derenzi at unipr.it subj: mulab
%
% If MULAB.mat exists in the path, loading it produces 
%
% the following global structures
% MU_GEAR (see below)
% MU_MODEL (help mufit)
% MU_PATH (help mupath)
% 
% If MULAB.mat does not exist in the path, mulab builds
% one anew, generating only the following global structure
% MU_GEAR, with fields FACILITY, INSTRUMENT, DATA_TYPE, 
% FILENAME_PREFIX, FILENAME_SUFFIX
% Remember to run mulabsave after a succesful fit.
%
% This is a function, so the main globals are loaded but 
% they do not appear automatically in the main workspace.
% To show what mulab generates type:  whos global 
% 
% See also MUFIT_GUI
%
% See HELP LOCAL/MULAB for an overview of innards   


fileversion=which('mulab.version');
fid=fopen(fileversion,'r'); 
string=fscanf(fid,'%s');
fclose(fid);
k=findstr(string,'%');
version=string(k(1)+1:k(2)-1);
k=findstr(version,'Version');
version=version(k+7:end);
localdir=pwd;

% list of Vital info for MULAB: must be provided even if MULAB.mat
% is not present or insufficient
% MU_VERSION, see above (automatic form distribution)
% MU_GEAR.FACILITY {'PSI' 'ISIS'}
% MU_GEAR.INSTRUMENT {'GPS' 'LTF' 'DOLLY' 'MUS' 'EMU' 'HIF'}
% MU_GEAR.DATA_TYPE {'MCS' 'NEXUS' 'ASCII' 'BIN']
% MU_GEAR.LBG 10 bins only for PSI
% MU_GEAR.RBG 10 bins only for PSI
% MU_GEAR.OFFSET 7-10 bins
% MU_GEAR.FILENAME_PREFIX {'gps' 'ltf' 'dol' 'mus' 'emu' 'hif'}
% MU_GEAR_FILENAME_SUFFIX {'dat' 'bin' 'raw' 'nxs'}
% sets up by default a DAMU fit model
% sets MU_PATH.LOG .DATA .ROOTDIR to the local dir, by default
% sets variables MU_FIG.MENU=1 MU_FIG.PLOT=2 MU_FIG.FIT=3, MU_FIT.FFT=4
% does not organize close_fcn for figures!
%
% vital but not set here
% MU_GEAR.NT0 as many as detectors, t=0 bin, 
% MU_GEAR.DT same, t=0 position with respect to center of NT0 bin
% are now either read from MULAB.mat and stored in MU_GEAR, 
% or calculated by MUSET and stored both in MU_DATA and in MU_GEAR
% If absent in MU_GEAR on a freshly lauched MULAB
% MULOAD and MULIST will obtain a guess from muguesst0
% MULOAD will store it in MU_GEAR.
global MU_MODEL MU_GEAR MU_PATH
global MU_FIG MU_VERSION

if exist('MULAB.mat')==2  % normal course
        %    yn=input('Clearing all globals. OK? [No]','s');
        % if isempty(yn) yn='n'; end
        % yn=lower(yn(1));
        %    if  yn=='y'
        clear global all
        load MULAB.mat
        disp('HELP MULAB, MUFIT_GUI for a skeleton description.')
        disp('Keep an eye on this COMMAND window:')
        disp('warnings, logs and Minuit output are shown here')
        MU_VERSION=version;
        mu_initialize_models
        %    else
        % disp('... save your globals and retry') % 
        % return
        % end
else % if MULAB.mat does not exist, build up the defaults
    disp('MULAB.mat does not exist. Creating one.')
    yn=input('Clearing all globals. OK? [No]','s');
    if isempty(yn) yn='n'; end
    yn=lower(yn(1));
    if  yn=='y'
        clear global all
        global MU_MODEL MU_GEAR MU_PATH
        global MU_FIG MU_VERSION
        MU_VERSION=version;
        nok=1;  
        while nok
            fac=input('Which facility (PSI, ISIS)? ','s');
            fac=upper(fac);
            switch fac
              case {'P','PS','PSI'}
                MU_GEAR.FACILITY='PSI';
                MU_GEAR.LBG=10; % bins only for PSI
                MU_GEAR.RBG=10 %bins only for PSI
                nok=0;
                nnok=1;
                while nnok
                    fac=input('Which instrument (GPS,LTF,DOLLY)? ','s');
                    fac=upper(fac);
                    switch fac
                      case {'G','GP','GPS'}
                        MU_GEAR.INSTRUMENT='GPS';
                        nnok=0;
                        s=input('Filename prefix [gps] ','s');
                        if isempty(s)
                            MU_GEAR.FILENAME_PREFIX='gps';
                        else
                            MU_GEAR.FILENAME_PREFIX=s;
                        end
                        MU_GEAR.OFFSET=7;
                      case {'L','LT','LTF'}
                        MU_GEAR.INSTRUMENT='EMU';
                        nnok=0;
                        s=input('Filename prefix [ltf] ','s');
                        if isempty(s)
                            MU_GEAR.FILENAME_PREFIX='ltf';
                        else
                            MU_GEAR.FILENAME_PREFIX=s;
                        end
                        MU_GEAR.OFFSET=10;
                      case {'D','DO','DOL','DOLL','DOLLY'}
                        MU_GEAR.INSTRUMENT='DOLLY';
                        nnok=0;                        
                        s=input('Filename prefix [dol] ','s');
                        if isempty(s)
                            MU_GEAR.FILENAME_PREFIX='dol';
                        else
                            MU_GEAR.FILENAME_PREFIX=s;
                        end
                        MU_GEAR.OFFSET=10;
                      otherwise
                        disp([fac '? Not clear, retry.'])
                    end
                end
                nnok=1;
                while nnok
                    fac=input('Which data type (ASCII,BIN)? ','s');
                    fac=upper(fac);
                    switch fac
                      case {'A','AS','ASC','ASCI','ASCII'}
                        MU_GEAR.DATA_TYPE='ASCII';
                        nnok=0;
                        s=input('Filename suffix [dat] ','s');
                        if isempty(s)
                            MU_GEAR.FILENAME_SUFFIX='dat';
                        else
                            MU_GEAR.FILENAME_SUFFIX=s;
                        end
                      case {'B','BI','BIN'}
                        MU_GEAR.DATA_TYPE='BIN';
                        nnok=0;
                        s=input('Filename suffix [bin] ','s');
                        if isempty(s)
                            MU_GEAR.FILENAME_SUFFIX='bin';
                        else
                            MU_GEAR.FILENAME_SUFFIX=s;
                        end
                      otherwise
                        disp([fac '? Not clear, retry.'])
                    end
                    MU_GEAR.OFFSET=7; % from prompt to first good
                end
              case {'I','IS','ISI','ISIS'}
                MU_GEAR.FACILITY='ISIS';
                nok=0;
                nnok=1;
                while nnok
                    fac=input('Which instrument (MUS,EMU,HIF)? ','s');
                    fac=upper(fac);
                    switch fac
                      case {'M','MU','MUS','MUSR'}
                        MU_GEAR.INSTRUMENT='MUS';
                        nnok=0;
                        s=input('Filename prefix [mus] ','s');
                        if isempty(s)
                            MU_GEAR.FILENAME_PREFIX='mus';
                        else
                            MU_GEAR.FILENAME_PREFIX=s;
                        end
                      MU_GEAR.OFFSET=7; % from prompt to first good
                      case {'E','EM','EMU'}
                        MU_GEAR.INSTRUMENT='EMU';
                        nnok=0;
                        s=input('Filename prefix [emu] ','s');
                        if isempty(s)
                            MU_GEAR.FILENAME_PREFIX='emu';
                        else
                            MU_GEAR.FILENAME_PREFIX=s;
                        end
                      MU_GEAR.OFFSET=7; % from prompt to first good
                      case {'H','HI','HIF'}
                        MU_GEAR.INSTRUMENT='HIF';
                        nnok=0;                        
                        s=input('Filename prefix [hif] ','s');
                        if isempty(s)
                            MU_GEAR.FILENAME_PREFIX='hif';
                        else
                            MU_GEAR.FILENAME_PREFIX=s;
                        end
                      MU_GEAR.OFFSET=7; % from prompt to first good
                      otherwise
                        disp([fac '? Not clear, retry.'])
                    end
                end
                nnok=1;
                while nnok
                    fac=input('Which data type (MCS,NEXUS)? ','s');
                    fac=upper(fac);
                    switch fac
                      case {'M','MC','MCS'}
                        MU_GEAR.DATA_TYPE='MCS';
                        nnok=0;
                        s=input('Filename suffix [dat] ','s');
                        if isempty(s)
                            MU_GEAR.FILENAME_SUFFIX='dat';
                        else
                            MU_GEAR.FILENAME_SUFFIX=s;
                        end
                     case {'N','NE','NEX','NEXU','NEXUS','NXS'}
                        MU_GEAR.DATA_TYPE='NEXUS';
                        nnok=0;
                        s=input('Filename suffix [nxs] ','s');
                        if isempty(s)
                            MU_GEAR.FILENAME_SUFFIX='nxs';
                        else
                            MU_GEAR.FILENAME_SUFFIX=s;
                        end
                      otherwise
                        disp([fac '? Not clear, retry.'])
                    end
                end
               otherwise
                disp([fac '? Not clear, retry.'])
            end
        end
        mu_initialize_models
        string=strvcat('See HELP CONTENTS');
        disp(string)
        
    else
        disp('... save your globals and retry') % 
        return
    end
end
% setup a standard 50 G damu fit
global MU_COMPONENT
MU_MODEL.NAME='damu';
switch MU_GEAR.FACILITY
  case 'PSI'
    MU_MODEL.RANGE=[1 7800];
    MU_MODEL.GROUPING.FORWARD=3;
    MU_MODEL.GROUPING.BACKWARD=4;
  case 'ISIS'
    MU_MODEL.RANGE=[1 1000];
    switch MU_GEAR.INSTRUMENT
      case 'EMU'
    MU_MODEL.GROUPING.FORWARD=1:16;
    MU_MODEL.GROUPING.BACKWARD=17:32;
      case 'MUS'
    MU_MODEL.GROUPING.FORWARD=33:64;
    MU_MODEL.GROUPING.BACKWARD=1:32;
    end
end
MU_MODEL.ALPHA=1;
MU_MODEL.FLAG.DENOMINATOR='Fit';% 'Data'
MU_MODEL.FLAG.TYPE='Polarization'; % 'Decay'
MU_MODEL.FLAG.LOGVERSION=1; 
MU_MODEL.BATCHMODE='Batch'; % 'Interactive'
MU_MODEL.BIN=1;
n=mugetcomponent(MU_MODEL.NAME); % gets the order number in  MU_COMPONENT list
l=length(n); % how may components
MU_MODEL.COMPONENTNUMBER=l;
par=0;
p=0;
for k=1:l;
    MU_MODEL.COMPONENT(k).NAME=char(MU_COMPONENT.NAME(n(k)));
    pnum=MU_COMPONENT.PARAMETER(n(k)).NUMBER;
    MU_MODEL.COMPONENT(k).PARAMETERNUMBER=pnum;
    pname=MU_COMPONENT.PARAMETER(n(k)).NAME;
    MU_MODEL.COMPONENT(k).SHARE=par+[1:pnum]; % index in p
    par=par+pnum;
    for j=1:MU_COMPONENT.PARAMETER(n(k)).NUMBER
        p=p+1;
        MU_MODEL.COMPONENT(k).PARAMETER(j).NAME= char(pname(j));
        MU_MODEL.COMPONENT(k).PARAMETER(j).VALUE=0;
        MU_MODEL.COMPONENT(k).PARAMETER(j).FLAG='~';
        MU_MODEL.COMPONENT(k).PARAMETER(j).SHARE=p;
    end
end

% set figure numbers and names
MU_FIG.MENU=1;
MU_FIG.MENUNAME='muLab FIT MENU';
MU_FIG.PLOT=2;
MU_FIG.PLOTNAME='muLab PLOT';
MU_FIG.FIT=3;
MU_FIG.FITNAME='muLab FIT';
MU_FIG.FFT=4;
MU_FIG.FFTNAME='muLab FFT of residues';
MU_FIG.PAR=5;
MU_FIG.PARNAME='muLab Plot fit parameters';

if isempty(varargin)
    mufit_gui
end
MU_PATH.ROOTDIR=localdir;
if ~isfield(MU_PATH,'LOG')
    MU_PATH.LOG=localdir;
end
if ~isfield(MU_PATH,'DATA')
    MU_PATH.DATA=localdir;
end
