function [znpin stpbnd parnames pf]=mupar(varargin)
% usage [mupin stpbnd parnames parfix]=mupar  
% generates fminut parameter list from fitted model (if MU_MODEL_F exists)
% 
% usage [mupin stpbnd parnames parfix]=mupar(1) 
% generates parameters from present model MU_MODEL 
% parnames is a cell array and must be translated into a blank
% separated string to be used in fminuit
%
% usage mupin=mupar(1,n)
%
% with e.g n=[1 3]
% generates only parameters corresponding to components n 
% mupin parameters out of MU_MODEL
% stpbnd their steps and bounds (see fminuit) 
% parnames their names
% parfix the number of non varying parameters 
% (fixed, shared, or linear relations)
global MU_COMPONENT MU_MODEL MU_MODEL_F  

znpin=[];
pf=0;
stpbnd=[];
par=0;
if ~isempty(varargin)|~isfield(MU_MODEL_F,'CHI')
    switch length(varargin)
%       case 1
%         cn=MU_MODEL.COMPONENTNUMBER; % use start guess
%         cm=ones(1,cn);
%         fit=0;
%         for k=1:cn
%             par=par+MU_MODEL.COMPONENT(k).PARAMETERNUMBER
%         end
      case 2 % use ony a subset of the parameters
        cn=MU_MODEL_F.COMPONENTNUMBER; % use fit results
        yes=cell2mat(varargin(2));
        cm=[];
        fit=1;
        for k=1:cn
            cm=[cm sum(k==yes)]; % cm is a mask, 
                                 %1,0 if component k is present/missing 
                                 % count only variable ~ 
                                 % or fixed ! parameters. Do not count
                                 % shared = or defined by linear relations +
            for j=1:MU_MODEL_F.COMPONENT(k).PARAMETERNUMBER;
                if findstr('~!',MU_MODEL_F.COMPONENT(k).PARAMETER(j).FLAG)
                    par=par+1;
                end
            end 
        end
      otherwise
        cn=MU_MODEL.COMPONENTNUMBER; % use start guess
        cm=ones(1,cn);
        fit=0;
        for k=1:cn
            % count only variable ~ or fixed ! parameters. Do not count
            % shared = or defined by linear relations +
            for j=1:MU_MODEL.COMPONENT(k).PARAMETERNUMBER;
                if findstr('~!',MU_MODEL.COMPONENT(k).PARAMETER(j).FLAG)
                    par=par+1;
                end
            end 
        end        
    end   
else  % isempty(varargin) & isfield(MU_MODEL_F,'CHI')
    cn=MU_MODEL_F.COMPONENTNUMBER; % use fit results
    cm=ones(1,cn);
    fit=1;
    for k=1:cn
        % count only variable ~ or fixed ! parameters. Do not count
        % shared = or defined by linear relations +
        for j=1:MU_MODEL_F.COMPONENT(k).PARAMETERNUMBER;
            if findstr('~!',MU_MODEL_F.COMPONENT(k).PARAMETER(j).FLAG)
                par=par+1;
            end
        end 
    end
end 

parnames=cell(1,par); % preallocate 

par=0;   % restart from zero
for k=1:cn %MU_MODEL.COMPONENTNUMBER
    if fit
        pn=MU_MODEL_F.COMPONENT(k).PARAMETERNUMBER;
        component=MU_MODEL_F.COMPONENT(k).NAME;
    else
        pn=MU_MODEL.COMPONENT(k).PARAMETERNUMBER;
        component=MU_MODEL.COMPONENT(k).NAME;
    end
    for j=1:pn %MU_MODEL.COMPONENT(k).PARAMETERNUMBER
        
        if fit
            parname=MU_MODEL_F.COMPONENT(k).PARAMETER(j).NAME;
            flag=MU_MODEL_F.COMPONENT(k).PARAMETER(j).FLAG;            
        else 
            parname=MU_MODEL.COMPONENT(k).PARAMETER(j).NAME;
            flag=MU_MODEL.COMPONENT(k).PARAMETER(j).FLAG;
        end
        parname(1)=upper(parname(1));
        
        if flag=='~'
            par=par+1;
            lowbnd=0;  % no bounds
            highbnd=0; % is overridden below in special cases        
            switch char(lower(parname))  % implies uniqe names for each
                                         % type of parameter               
              case {'lpha','amp'}
                error=0.01; % asymmetry
              case 'gau'
                error=5; % G
                switch MU_MODEL.COMPONENT(k).NAME
                  case 'kg','kg'
                    lowbnd=0.001; % bounds 10 times less
                    highbnd=100000; % and 10 times more than physical limits 
                end
              case 'phi'
                error=10; % degrees
              case {'delo','dega'}
                error=0.1; % us^-1
              case {'decr' 'deg' 'del'} % deg and del are the
                                        % positive-limited cases of
                                        % dega and delo (e.g. Kubo
                                        % Toyabe, stretched exponential)
                
                error=0.1; % us^-1
                lowbnd=0.001; % bounds 10 times less
                highbnd=1000; % and 10 times more than physical limits 
              case 'beta'
                error=0.1; % exponent
                lowbnd=0.1; % bounds 3 times less
                highbnd=6; % and 3 times more than physical limits 
            end
            parnames(par)={[component parname]};
            stpbnd=[stpbnd; par error lowbnd highbnd];
            if fit
                znpin=[znpin ...
                       MU_MODEL_F.COMPONENT(k).PARAMETER(j).VALUE*...
                       cm(k)];
                % cm(k) is the mask, zeroes the unwanted components
            else
                znpin=[znpin ...
                       MU_MODEL.COMPONENT(k).PARAMETER(j).VALUE*...
                       cm(k)];
                % cm(k) is the mask, zeroes the unwanted components
           end
        elseif flag=='!'
            par=par+1;
            pf=pf+1;
            parnames(par)={[component parname]};
            stpbnd=[stpbnd; par 0 0 0];
            if fit
                znpin=[znpin ...
                       MU_MODEL_F.COMPONENT(k).PARAMETER(j).VALUE*cm(k)]; ...
                % cm(k) is the mask, zeroes the unwanted components
            else
                znpin=[znpin ...
                       MU_MODEL.COMPONENT(k).PARAMETER(j).VALUE*cm(k)]; ...
                % cm(k) is the mask, zeroes the unwanted components
            end                
        end	
        % shared '=' and linear relation '+' parameters are not 
        % passed to minuit 
    end
end