function muplot(varargin)
% usage MUPLOT
%
% direct plot routine with command input interface
%
% usage MUPLOT(HISTO,RANGE) 
% HISTO = detector number, integer
% RANGE = start bin stop bin, integer array, e.g. [1 500]
global MU_DATA MU_PLOT MU_FIG MU_ADD

if ~isstruct(MU_DATA)
    disp('Load data first!')
    return
end

lengthplot=size(MU_DATA.DATA,1);
numhisto=size(MU_DATA.DATA,2);

if ~isfield(MU_PLOT,'RANGE')
    MU_PLOT.RANGE=[1 500];
end
if ~isfield(MU_PLOT,'HISTO')
    MU_PLOT.HISTO=1;
end

if isempty(varargin)
    OK=0;
    while ~OK
        range=input(['Histo, bin range (0 to quit): [' ...
                     int2str(MU_PLOT.HISTO) '  ' ...
                     int2str(MU_PLOT.RANGE) '] '],'s');
        range=str2num(range);

        if length(range)==1
            if ~range
                OK=1; % only way out, answering 0 
            elseif range>=1&range<=numhisto
                MU_PLOT.HISTO=range;
            else
                disp(['  wrong histo ' ...
                      num2str(range)])
                 if range(1)>numhisto, MU_PLOT.HISTO=numhisto; end
            end
        elseif length(range)==2
            if  range(1)<range(2) & range(1)>0 ...
                    & range(2)<lengthplot 
                MU_PLOT.RANGE=range;
            else
                disp(['  wrong range ' ...
                      num2str(range)])
                if range(1)<1, MU_PLOT.RANGE(1)=1; end
                if range(2)>lengthplot, MU_PLOT.RANGE(2)=lengthplot; end
            end
        elseif length(range)==3
            if range(1)>=1 & range(1)<=numhisto & range(2)<range(3) & ...
                    range(2)>0 & range(3)<lengthplot
                MU_PLOT.HISTO=range(1);
                MU_PLOT.RANGE=range(2:3);
            else
                disp(['  wrong answer ' ...
                      num2str(range)])
                if range(1)>numhisto, MU_PLOT.HISTO=numhisto; end
                if range(2)<1, MU_PLOT.RANGE(1)=1; end
                if range(3)>lengthplot, MU_PLOT.RANGE(2)=lengthplot; end
            end
        elseif ~isempty(range)
            disp(['  wrong answer ' ...
                  num2str(range)])
        end
        if isempty(range), range=-1; end
        if range
            muplot(MU_PLOT.HISTO,MU_PLOT.RANGE);
        end
    end
elseif length(varargin)==2
    histo=cell2mat(varargin(1));
    range=cell2mat(varargin(2));
    if histo~=MU_PLOT.HISTO 
        if histo>=1 & histo<=numhisto    
            MU_PLOT.HISTO=histo;
        else 
            disp([' wrong histo ' num2str(histo)])
            disp('Enter txt command mode (help muplot)')
            return
        end
    end
    if range(1)~=MU_PLOT.RANGE(1)|range(2)~=MU_PLOT.RANGE(2)
        if range(1)<range(2) & range(1)>0 & range(2)<lengthplot
            MU_PLOT.RANGE=range;
        else
            disp([' wrong range ' num2str(range)])
            disp('Enter txt command mode (help muplot)')
            return
        end
    end
    figure(MU_FIG.PLOT)
    set(MU_FIG.PLOT,'Name',MU_FIG.PLOTNAME,'Visible','off',...
              'MenuBar','None');
    clf

    empty=[];
    Xmin=0.085;
    Ymin=0.1;
    Xwidth=0.8-Xmin;
    Ywidth=0.88-Ymin;
    hiamp=axes('position',[Xmin Ymin Xwidth Ywidth]);
    
    x=MU_PLOT.RANGE(1):MU_PLOT.RANGE(2);
    y=MU_DATA.DATA(x,MU_PLOT.HISTO);
    bar(x,y) %    plot(x,y,'.')
    xlabel(['Bin (' num2str(MU_DATA.RESNS) ' ns/bin)'])
    ylabel('Positron counts')

    xy=[min(x) max(x) 0 max(y)*1.1];
    axis(xy);
    dy=xy(4)-xy(3);
    ytext=xy(4)+0.06*dy;
    dtext=(xy(2)-xy(1))*0.02;
    blue=[.2 .2 .8];
    fsiz=11;
    if isempty(MU_ADD)
        runs=int2str(MU_DATA.NRUN);
    else
        l=length(MU_ADD);
        runs=[int2str(MU_DATA.NRUN) '+' int2str(MU_ADD)];
    end
    text(xy(1)-dtext,ytext,[runs '   ' MU_DATA.SAMPLE ...
                        MU_DATA.TEMPERATURE ' ' MU_DATA.FIELD ...
                        ' ' MU_DATA.ORIENTATION] ...
         ,'fontsize',fsiz,'fontweight','demi','color',blue)
    fsizlab=20;
    text(xy(2)+3*dtext,ytext+0.02*dy,'\mu lab',...
         'fontsize',fsizlab,'fontweight','demi',...
         'fontname','Arial','color',blue);
    ytext=xy(3)+0.82*dy;
    text(xy(2)+1.8*dtext,ytext,['Detector '  int2str(MU_PLOT.HISTO)]...
         ,'fontsize',fsiz,'fontweight','demi','color',blue)
X=0.82;
Y=0.6;
dY=0.07;
Xtwidth=0.14;
Ytwidth=0.05;
tag='Histo';
htxthisto = uicontrol('Parent',MU_FIG.PLOT,...
                      'Style','text',...
                      'String','Detector',...
                      'Horizontalalignment','Left',...
                      'Units','normalized',...
                      'Position',...
                      [X,Y,Xtwidth,Ytwidth]);
Y=Y-0.9*dY;
hhisto=uicontrol('Parent',MU_FIG.PLOT,...
                 'Style','Edit',...
                 'String',num2str(MU_PLOT.HISTO),...
                 'Tag',tag,...
                 'Callback',@Plot_CallBack,...
                 'Horizontalalignment','Left',...
                 'Units','normalized',...
                 'Position',...
                 [X,Y,Xtwidth/2,Ytwidth],...
                 'Backgroundcolor','white');
Y=Y-dY;
tag='Range';
htxtrange = uicontrol('Parent',MU_FIG.PLOT,...
                      'Style','text',...
                      'String','Range',...
                      'Units','normalized',...
                      'Horizontalalignment','Left',...
                      'Position',...
                      [X,Y,Xtwidth,Ytwidth]);
Y=Y-0.9*dY;
hrange=uicontrol('Parent',MU_FIG.PLOT,...
                 'Style','Edit',...
                 'String',num2str(MU_PLOT.RANGE),...
                 'Tag',tag,...
                 'Callback',@Plot_CallBack,...
                 'Horizontalalignment','Left',...
                 'Units','normalized',...
                 'Position',...
                 [X,Y,Xtwidth,Ytwidth],...
                 'Backgroundcolor','white');
Y=Y-dY;
tag='Quit';
hquit=uicontrol('Parent',MU_FIG.PLOT,...
                 'Style','pushbutton',...
                 'String','Quit',...
                 'Tag',tag,...
                 'Callback',@Plot_CallBack,...
                 'Units','normalized',...
                 'Position',...
                 [X,Y,Xtwidth,Ytwidth],...
                 'Backgroundcolor','white');
else
    eval('help muplot')
    disp('Enter txt command mode (just type muplot)')
end
set(MU_FIG.PLOT,'Visible','On');


function Plot_CallBack(varargin)
global MU_PLOT MU_DATA MU_FIG

handle=cell2mat(varargin(1));
switch get(handle,'Tag')
  case 'Histo'
    histo=str2num(get(handle,'String'));
    if histo>=1 && histo<=size(MU_DATA.DATA,2)
        MU_PLOT.HISTO=histo;
        muplot(MU_PLOT.HISTO,MU_PLOT.RANGE)
    else
        set(handle,'String',num2str(MU_PLOT.HISTO))
    end
  case 'Range'
    range=str2num(get(handle,'String'));
    if range(1)>=1 && range(2)<=size(MU_DATA.DATA,1) &&...
                 range(2)>range(1)
        MU_PLOT.RANGE=range;
        muplot(MU_PLOT.HISTO,MU_PLOT.RANGE)
    else
        set(handle,'String',num2str(MU_PLOT.RANGE))
    end
  case 'Quit'
    figure(MU_FIG.PLOT)
    set(MU_FIG.PLOT,'Visible','Off');
    mufit_gui(1) % bring back focus to menu
end