function muplotfit(varargin)
% usage MUPLOTFIT or MUPLOTFIT(2)
% 
% plot fit result
%
% usage MUPLOTFIT(1)
% 
% plot fit starting guess
%
% usage MUPLOTFIT(1,RANGE)
% 
% plot fit starting guess over RANGE=[startbin stopbin] 
% e.g. RANGE=[1 200]
%
% usage MUPLOTFIT(2,RANGE)
% 
% plot fit result over RANGE=[startbin stopbin] 
% e.g. RANGE=[1 200]

global MU_DATA
global MU_MODEL
global MU_MODEL_F
global MU_ADD
global MU_FIG


red=[0.9 0.2 0.2];
green=[0.2 0.7 0.3];
blue=[0.1 0.1 0.7];
orange=[0.9 0.5 0.1];
purple=[0.7 0.3 0.5];
colormap(lines)
startguess=1; % starting guess
if isempty(varargin)&isfield(MU_MODEL_F,'CHI')
    startguess=[];
    startbin=MU_MODEL.RANGE(1);
    stopbin=MU_MODEL.RANGE(2);
elseif length(varargin)==2
    flag=cell2mat(varargin(1));
    if flag==2, startguess=[]; end
    range=cell2mat(varargin(2));
    startbin=range(1);
    stopbin=range(2);
else
    flag=cell2mat(varargin);
    if flag==2, startguess=[]; end
    startbin=MU_MODEL.RANGE(1);
    stopbin=MU_MODEL.RANGE(2);
end
%
% recalculate array SHARE which redistributes parameters
% must have as many elements as the total number of parameters
% but share(j) is the index of par inside fminuit 
% where += parameters do not appear
shareglobal=[];
par=0;
for k=1:MU_MODEL.COMPONENTNUMBER
    share=[]; % this is the component SHARE array
    for j=1:MU_MODEL.COMPONENT(k).PARAMETERNUMBER
        switch MU_MODEL.COMPONENT(k).PARAMETER(j).FLAG
          case {'~','!'}
            par=par+1; % index is incremented only for ~! parameters
            share=[share par];
            shareglobal=[shareglobal par];
          case '+'
            share=[share 0];
            shareglobal=[shareglobal 0];
          case '=' % must be a preceding parameter
                parshared=MU_MODEL.COMPONENT(k).PARAMETER(j).SHARE;
                share=[share shareglobal(parshared)];
                shareglobal=[shareglobal shareglobal(parshared)];
        end
    end
    %       disp (['comp=' num2str(k) ': ' num2str(share)])
    MU_MODEL.COMPONENT(k).SHARE=share;
end
muasymmetry;
data=[MU_DATA.TIME(startbin:stopbin); ...
      MU_DATA.ASYMMETRY(startbin:stopbin); ...
      MU_DATA.ASYMERROR(startbin:stopbin)];
if isempty(startguess)
    [mupout dum dumm pf]=mupar; % reads mupout from MU_MODEL_F 
else
    [mupout dum dumm pf]=mupar(startguess); % reads mupout from MU_MODEL 
end
nu=length(data(1,:))-(length(mupout)-pf); % degrees of freedom
chi=fcn(mupout,data);


dt=data(1,2)-data(1,1);
tmin=min(data(1,:))-2*dt/3;
tmax=max(data(1,:))+2*dt/3;
tfit=tmin:dt/3:tmax;
figure(MU_FIG.FIT);
clf
set(MU_FIG.FIT,'Name',MU_FIG.FITNAME,'Visible','off',...
              'MenuBar','None');

empty=[];
Xmin=0.1;
Ymin=0.1;
Yres=0.3;
Xwidth=0.7;
Ywidth=0.92-Ymin-Yres;

hres=axes('position',[Xmin Ymin Xwidth Yres]);

res=data(2,:)-fcn(mupout,data(1,:));
%rmin=min(res);
%rmax=max(res);
%dr=rmax-rmin;
%rmin=rmin-0.05*dr;
%rmax=rmax+0.05*dr;
%dr=1.1*dr;
hold(gca,'all')
[x y ey]=murebin(data(1,:),res,data(3,:));
ymin=min(y);
ymax=max(y);
ymin=min([ymin 0]);
ymax=max([ymax 0]);
dy=ymax-ymin;
ymin=ymin-0.05*dy;
ymax=ymax+0.05*dy;
dy=1.1*dy;
%length(x)
%errorbar(x,y,ey,'b.');
lwdt=2;
if length(x)>3000
    plot(x(1:4:end),y(1:4:end),'m.','color',purple)
    plot(x,ey,'g-.','color',green,'linewidth',lwdt)
    plot(x,-ey,'g-.','color',green,'linewidth',lwdt)
    plot(x,2*ey,'y-','color',orange,'linewidth',lwdt)
    plot(x,-2*ey,'y-','color',orange,'linewidth',lwdt)   
elseif length(x)>1000&length(x)<3000
    plot(x(1:2:end),y(1:2:end),'m.','color',purple)
    plot(x,ey,'g-.','color',green,'linewidth',lwdt)
    plot(x,-ey,'g-.','color',green,'linewidth',lwdt)
    plot(x,2*ey,'y-','color',orange,'linewidth',lwdt)
    plot(x,-2*ey,'y-','color',orange,'linewidth',lwdt)
else
    plot(x,y,'m.','color',purple)
    plot(x,ey,'g-.','color',green,'linewidth',lwdt)
    plot(x,-ey,'g-.','color',green,'linewidth',lwdt)
    plot(x,2*ey,'y-','color',orange,'linewidth',lwdt)
    plot(x,-2*ey,'y-','color',orange,'linewidth',lwdt)
end
xlabel('time (\mu s)')
ylabel('Residues')
axis([tmin tmax ymin ymax])
hold(gca,'off')
hhist=axes('position',[Xmin+Xwidth+0.01 Ymin 1-Xmin-Xwidth-0.02 Yres]);
hold(gca,'all')
h=hist(y./ey,[-5:5]);
bar([-5:5],h)
xh=[-5:0.2:5];
nuc=nu-length(data(1,:))+length(x); % degrees of freedom for
                                    % rebinned residues
yh=nuc*(normcdf(xh+0.5,0,1)-normcdf(xh-0.5,0,1)); % expected yield for nuc
% gaussian extractions to fall within xh+-0.5 std
% notice that bar histo is with bins=1 std whereas yellow curve
% (yh) is sampled every 0.2*std
plot(xh,yh,'y-','color',orange,'linewidth',2)
set(gca,'yticklabel',empty,'box','on')
axis([-5 5 0 1.05*max([h yh])])
%set(gca,'xticklabel',{[],'-4',[],'-2',[],'0',[],'2',[],'4',[]})
hold(gca,'off')
hplot=axes('position',[Xmin Ymin+Yres Xwidth Ywidth]);
hold(gca,'all')

[x y ey]=murebin(data(1,:),data(2,:),data(3,:));
ymin=min(y);
yfit=fcn(mupout,tfit);
fmin=min(yfit);
ymin=min([ymin fmin]);
ymax=max(y);
fmax=max(yfit);
ymax=max([ymax fmax]);
dy=ymax-ymin;
ymin=ymin-0.05*dy;
ymax=ymax+0.05*dy;
dy=1.1*dy;
he=errorbar(x,y,ey,'r.','markerfacecolor',red,...
         'markeredgecolor',red);
plot(tfit,yfit,'g-','linewidth',2,'color',green)%,data(1,:),data(2,:),'m-')

ylabel('Asymmetry')
set(gca,'xticklabel',empty,'box','on')
axis([0 tmax ymin ymax])
dtext=0.02*(tmax-tmin);
%blue=[.2 .2 .8];
fsiz=11;
da=dy;
amax=ymax;
amin=ymin;
ytext=amax+0.06*da;
if isempty(MU_ADD)
    runs=int2str(MU_DATA.NRUN);
else
    arun=num2str(MU_ADD(1));
    for k=2:length(MU_ADD)
        arun=[arun '+' num2str(MU_ADD(k))];
    end
    runs=[int2str(MU_DATA.NRUN) '+' arun];
end
text(tmin-dtext,ytext,[runs '   ' MU_DATA.SAMPLE ...
                   MU_DATA.TEMPERATURE ' ' MU_DATA.FIELD ...
                    ' ' MU_DATA.ORIENTATION,],...
    'fontsize',fsiz,'fontweight','demi','color',blue)

ytext=amin+1.02*da;
fsiz=20;
text(tmax+3*dtext,ytext+0.02*da,'\mu lab','fontsize',fsiz,'fontweight','demi','fontname','Arial','color',blue);
ytext=amin+0.55*da;
text(tmax+dtext,ytext,['F:[' musgroup(1,0) ']'],'fontsize',8);
ytext=amin+0.45*da;
text(tmax+dtext,ytext,['B:[' musgroup(2,0) ']'],'fontsize',8);
ytext=amin+0.35*da;
%string=valerror(ZN_TEMPER(1),ZN_TEMDEV(1));
%text(tmax+dtext,ytext,['T=' string],'fontsize',8);
if isempty(startguess) % it's a fit
    ytext=amin+0.71*da;
    text(tmax+dtext,ytext,['\alpha=' num2str(MU_MODEL_F.ALPHA) ...
                        ',  binned ' num2str(MU_MODEL.BIN) ],'fontsize',8);
    ytext=amin+0.92*da;
    text(tmax+dtext,ytext,['Fit at ' MU_MODEL_F.TIME],'fontsize',8);
    ytext=amin+0.84*da;
    text(tmax+dtext,ytext,['on ' MU_MODEL_F.DATE],'fontsize',8);
else
    ytext=amin+0.71*da;
    text(tmax+dtext,ytext,['\alpha=' num2str(MU_MODEL.ALPHA)...
                        ',  binned ' num2str(MU_MODEL.BIN) ],'fontsize',8);
    ytext=amin+0.92*da;
    text(tmax+dtext,ytext,['Guess, run start ' MU_DATA.START_TIME],'fontsize',8);
    ytext=amin+0.84*da;
    text(tmax+dtext,ytext,['on ' MU_DATA.START_DATE],'fontsize',8);
end    
ytext=amin+0.2*da;

    %     a way to get 2 sigma for chi2
    m=round(nu/4);
    k=[-m:m];
    cc=muchi2cdf(k+nu,nu);
    lc=1+k(min(find(cc<0.95&cc>0.05)))/nu;
    hc=1+k(max(find(cc<0.95&cc>0.05)))/nu;

text(tmax+dtext,ytext,['\chi^2_r=' num2str(chi/nu,3) '(' num2str(lc,2) ...
     ',' num2str(hc,3) ')' ]);
ytext=amin+0.05*da;
text(tmax+dtext,ytext,['\chi^2_{cdf}=' num2str(muchi2cdf(chi,nu))]);
hold(gca,'off')
set(MU_FIG.FIT,'Visible','on')

