function musummary(c,nu,t0,t1,dt)
%
% Invoked by mufit
%
% Produces an output in the command window, a readable log file 
% and an addition in a logzen-style 
% file (a matrix of numbers, separated by spaces, alternating a
% parameter and it error, according to the fminuit list,
% i.e. shared parameters and those fixed by linear relations are
% skipped)
%
% Filenames are formed by model name, run number, grouping tag,
% version, e.g.
%
% mubaba.3-4_1.dat     the logzen-style file, contains a line for
% each mubaba fit, log version 1 in this directory, ordered by run number
%
% mubaba.5234.3-4_1.log contains a copy of the command window output
    
    
    
    global MU_MODEL_F
    global MU_DATA
    global MU_ADD
    global MU_PATH
    %     a way to get 2 sigma for chi2
    m=round(nu/4);
    k=[-m:m];
    cc=muchi2cdf(k+nu,nu);
    lc=1+k(min(find(cc<0.95&cc>0.05)))/nu;
    hc=1+k(max(find(cc<0.95&cc>0.05)))/nu;
    %    grouping

    if isempty(MU_ADD)
        
        disp(['Run ' int2str(MU_DATA.NRUN) ':     "' MU_DATA.SAMPLE ' ' ...
              MU_DATA.ORIENTATION ' ' MU_DATA.TEMPERATURE ...
              MU_DATA.FIELD '"']); 
    else
        l=length(MU_ADD);
        runs=[num2str(MU_DATA.NRUN) '+' num2str(MU_ADD)];
        disp(['Runs ' runs ':     "' MU_DATA.SAMPLE ' ' ...
              MU_DATA.ORIENTATION ' ' MU_DATA.TEMPERATURE ...
              MU_DATA.FIELD '"']); 
    end
% '" T_sample=' valerror(ZN_TEMPER(1),ZN_TEMDEV(1)) 'K' ]);
str=char(45*ones(1,80));
log=[num2str(MU_MODEL_F.NRUN) ' ' MU_DATA.TITLE];
log=strvcat(log,str);
disp(str)
str=['Alpha=' num2str(MU_MODEL_F.ALPHA) ', fit from ' ...
num2str(t0*1000) 'ns to ' num2str(t1) 'us, ' ...
      'FGroup=' musgroup(1,0) ' BGroup=' musgroup(2,0) ...
     ];
disp(str)
log=strvcat(log,str);
str=['Chi2r=' num2str(c/nu) ' (' num2str(lc) ',' num2str(hc) ')'...
      '    -   Performed on ' MU_MODEL_F.DATE ' at ' MU_MODEL_F.TIME];
disp(str);
log=strvcat(log,str);
str=char(45*ones(1,80));
disp(str)
log=strvcat(log,str);
summary=[];
sumrow=[];
c=0;
col=5;
cn=MU_MODEL_F.COMPONENTNUMBER;

for k=1:cn %MU_MODEL.COMPONENTNUMBER
    pn=MU_MODEL_F.COMPONENT(k).PARAMETERNUMBER;
    component=MU_MODEL_F.COMPONENT(k).NAME;
    for j=1:pn %MU_MODEL.COMPONENT(k).PARAMETERNUMBER
        c=c+1;
        flag=MU_MODEL_F.COMPONENT(k).PARAMETER(j).FLAG;
        parname=MU_MODEL_F.COMPONENT(k).PARAMETER(j).NAME;
        parname(1)=upper(parname(1));
        v=MU_MODEL_F.COMPONENT(k).PARAMETER(j).VALUE;
        e=MU_MODEL_F.COMPONENT(k).PARAMETER(j).ERROR;
        if flag=='~'|flag=='!'
            ve=valerror(v,e);
        else
            ve='  ';
        end
        if c>col
            c=0;
            summary=strvcat(summary,sumrow);
            sumrow=[];
        else
            sumrow=[sumrow component parname '=' ve flag '  '];
        end
    end
    c=0;
    summary=strvcat(summary,sumrow);
    sumrow=[];
end
if c>0
    summary=strvcat(summary,sumrow);
end

disp(summary)
log=strvcat(log,summary);
if ~isfield(MU_MODEL_F.FLAG,'LOGVERSION')
    MU_MODEL.FLAG_F.LOGVERSION=1;
end
fid=fopen([MU_PATH.LOG MU_MODEL_F.NAME '.' num2str(MU_DATA.NRUN) ...
           '.' mugrouptag '_' MU_MODEL_F.FLAG.LOGVERSION '.log'],'w');

for k=1:size(log,1)
    fprintf(fid,'%s\n',log(k,:));
end
fclose(fid);

MU_MODEL_F.NRUN=MU_DATA.NRUN; % save which run is this the best
                              % fit of

% New: old style logzen
%
% WARNING: for this to work all fits in this model must have the
% same number of minuit parameters, i.e. one CANNOT switch between
% sharing a parameter and fixing it (one more minuit parameter)
% so musummary must check that the number p of parameter remains
% the same
%
% First construct logzen header and filename
head='% run  T(K) B(G) ';
for k=1:MU_MODEL_F.COMPONENTNUMBER
    component=MU_MODEL_F.COMPONENT(k).NAME;
    for j=1:MU_MODEL_F.COMPONENT(k).PARAMETERNUMBER
        switch MU_MODEL_F.COMPONENT(k).PARAMETER(j).FLAG
          case {'~','!'}
            head=[head ' ' ...
                  component ... ...
                  MU_MODEL_F.COMPONENT(k).PARAMETER(j).NAME ' e ']; ...
            %RDR check: should add an e after each par in the first
            %line, after % run T(K) B(G) 
        end
    end
end
logzenfile=[MU_PATH.LOG MU_MODEL_F.NAME ...
            '.' mugrouptag '_' MU_MODEL_F.FLAG.LOGVERSION '.dat'];
if ~exist(logzenfile)
    % if logzen does not exist create one and write
    this=[MU_MODEL_F.NRUN ...
          str2num(MU_MODEL_F.TEMPERATURE(1:end-1)) ...
          str2num(MU_MODEL_F.FIELD(1:end-1))];
    p=0;
    for k=1:MU_MODEL_F.COMPONENTNUMBER
        for j=1:MU_MODEL_F.COMPONENT(k).PARAMETERNUMBER
            switch MU_MODEL_F.COMPONENT(k).PARAMETER(j).FLAG
              case {'~','!'}
                p=p+1;
                this=[this  MU_MODEL_F.PAR(p) ...
                      MU_MODEL_F.EPAR(p)];
            end
        end
    end
    % convert to formatted string
    string=[num2str(this(1)) ' ' num2str(this(2),4) ' ' num2str(this(3),4)];
    for k=4:2:length(this)
        string=[string ' ' num2str(this(k),4) ' ' num2str(this(k+1),1)];
    end
    fid=fopen(logzenfile,'w');
    fprintf(fid,'%s\n',head);
    fprintf(fid,'%s\n',string);
    fclose(fid);
    disp(['Logbook file ' logzenfile ' saved'])

else % logzen exists
    % first write temporary string for this run
    this=[MU_MODEL_F.NRUN ...
          str2num(MU_MODEL_F.TEMPERATURE(1:end-1)) ...
          str2num(MU_MODEL_F.FIELD(1:end-1))];
    p=0;
    for k=1:MU_MODEL_F.COMPONENTNUMBER
        for j=1:MU_MODEL_F.COMPONENT(k).PARAMETERNUMBER
            switch MU_MODEL_F.COMPONENT(k).PARAMETER(j).FLAG
              case {'~','!'}
                p=p+1;
                this=[this  MU_MODEL_F.PAR(p) ...
                      MU_MODEL_F.EPAR(p)];
            end
        end
    end
    % p is the number of minuit parameters

    % then, since logzen run exists, read it all
    logzen=load(logzenfile,'-ascii'); % reads numbers into a matrix 
    % find out if the present run number (first item) was already present
    k=find(logzen(:,1)==MU_DATA.NRUN); % it is the first item on each row
    psummary=(size(logzen,2)-3)/2; % first three are run T B
    if (p~=psummary) % different number of parameters!
        % mv old logzen, appending a nearly unique tag
        r=floor(65+52*rand(1,2));
        r=r+6*(r>90).*(r<97); % only ASCII for letters (90 to 96 are
                             % symbols
        randtag=char(r);
        system(['mv ' logzenfile ' ' logzenfile '.' randtag]);
        disp('Warning! Fit model changed number of Minuit parameters')
        disp(['Moved old .dat file to .dat.' randtag])
        zenout=this;
    else
        if isempty(k) 
            % this run is not yet logged
            % determine where is this run positioned in the list (order
            % by run) 
            nruns=logzen(:,1);        
            kk=find(nruns<MU_DATA.NRUN); % indices of nruns less than present
            nn=max(nruns(kk)); % max nrun less than present (may be
                               % zero or 
            if isempty(nn) % present run comes first
                zenout=this;
                zenout=[zenout; logzen];
            else  % there is at least one run in the list before this
                k=kk(find(nn==nruns(kk))); % index of max nrun less than present
                                           % write out the runs before
                zenout=logzen(1:k,:); % k may be equal to end
                zenout=[zenout; this]; % then present run
                zenout=[zenout; logzen(k+1:end,:)]; % the write out the
                                                    % rest (if k=end it
                                                    % adds nothing)
        end
        else
            % present run is k-th on the list, write the first k-1
            zenout=logzen(1:k-1,:);
            zenout=[zenout; this]; % replace k-th with present 
                                   % then write out the rest
            zenout=[zenout; logzen(k+1:end,:)]; % if k=end nothing is added
        end
    end
    % now fprintf the new log
    % convert to formatted string
    fid=fopen(logzenfile,'w');
    fprintf(fid,'%s\n',head);
    for k=1:size(zenout,1)
        row=[num2str(zenout(k,1)) ' ' num2str(zenout(k,2),4) ...
                ' ' num2str(zenout(k,3),4)];
        for j=4:2:size(zenout,2)
            row=[row ' ' num2str(zenout(k,j),4) ...
                    ' ' num2str(zenout(k,j+1),1)];
        end
        fprintf(fid,'%s\n',row);
    end
    fclose(fid);
    disp(['Logbook file ' logzenfile ' saved'])
end